# MiCADO Client Library

A Python client library for MiCADO (github.com/micado-scale) to support the following:
- Create an ADT
- Deploy, update and delete an application in MiCADO
- Create and destroy a MiCADO node

This package also exposes a CLI, which is [documented here](https://micado-scale.github.io/install/cli-install/).
